        function getT(rr,cc){
       if(rr==5 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==5 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 33 <strong>control</strong><br>0,4,5,8,11,12,13,15,16,18,19,20,21,22,23,25,26,27,28,30,31,32,34,35,36,37,39,40,43,44,47,49,50';}
       if(rr==5 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 18 <br>1,2,3,6,7,9,10,14,17,24,29,33,38,41,42,45,46,48';}
       if(rr==40 && cc==0){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==40 && cc==1){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 33 <strong>control</strong><br>0,4,5,8,11,12,13,15,16,18,19,20,21,22,23,25,26,27,28,30,31,32,34,35,36,37,39,40,43,44,47,49,50';}
       if(rr==40 && cc==2){return '<strong>Probabilidad cielo despejado N=0,1</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 18 <br>1,2,3,6,7,9,10,14,17,24,29,33,38,41,42,45,46,48';}
       if(rr==41 && cc==0){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==41 && cc==1){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 33 <strong>control</strong><br>0,4,5,8,11,12,13,15,16,18,19,20,21,22,23,25,26,27,28,30,31,32,34,35,36,37,39,40,43,44,47,49,50';}
       if(rr==41 && cc==2){return '<strong>Probabilidad cielo poco nuboso N=2,3</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 18 <br>1,2,3,6,7,9,10,14,17,24,29,33,38,41,42,45,46,48';}
       if(rr==42 && cc==0){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==42 && cc==1){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 33 <strong>control</strong><br>0,4,5,8,11,12,13,15,16,18,19,20,21,22,23,25,26,27,28,30,31,32,34,35,36,37,39,40,43,44,47,49,50';}
       if(rr==42 && cc==2){return '<strong>Probabilidad cielo nuboso N=4,5,6</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 18 <br>1,2,3,6,7,9,10,14,17,24,29,33,38,41,42,45,46,48';}
       if(rr==43 && cc==0){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br><strong>control +<br>EPS</strong>';}
       if(rr==43 && cc==1){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>1</strong> representante: <strong>27</strong> miembros: 33 <strong>control</strong><br>0,4,5,8,11,12,13,15,16,18,19,20,21,22,23,25,26,27,28,30,31,32,34,35,36,37,39,40,43,44,47,49,50';}
       if(rr==43 && cc==2){return '<strong>Probabilidad cielo cubierto N=7,8</strong><br><br><strong>20260508 a 00</strong> UTC HH+204 (rango:192-216)<br>grupo: <strong>2</strong> representante: <strong>45</strong> miembros: 18 <br>1,2,3,6,7,9,10,14,17,24,29,33,38,41,42,45,46,48';}
}
